@@ -23,7 +23,7 @@
    Supports:
 	Intel PIIX4, 440MX
 	Serverworks OSB4, CSB5, CSB6, HT-1000
-	ATI IXP200, IXP300, IXP400, SB600
+	ATI IXP200, IXP300, IXP400, SB600, SB700, SB800
 	SMSC Victory66
 
    Note: we assume there can only be one device, with one SMBus interface.
@@ -38,19 +38,11 @@
 #include <linux/ioport.h>
 #include <linux/i2c.h>
 #include <linux/init.h>
-#include <linux/apm_bios.h>
 #include <asm/io.h>
 #include "version.h"
 #include "sensors_compat.h"
 
 
-struct sd {
-	const unsigned short mfr;
-	const unsigned short dev;
-	const unsigned char fn;
-	const char *name;
-};
-
 /* PIIX4 SMBus address offsets */
 #define SMBHSTSTS (0 + piix4_smba)
 #define SMBHSLVSTS (1 + piix4_smba)
@@ -103,8 +95,6 @@ MODULE_PARM_DESC(force_addr,
 		 "Forcibly enable the PIIX4 at the given address. "
 		 "EXTREMELY DANGEROUS!");
 
-static int piix4_transaction(void);
-
 static unsigned short piix4_smba = 0;
 static struct pci_driver piix4_driver;
 
@@ -113,9 +103,10 @@ static struct pci_driver piix4_driver;
  * Get DMI information.
  */
 
+extern int is_unsafe_smbus;
+
 static int __devinit ibm_dmi_probe(void)
 {
-	extern int is_unsafe_smbus;
 	return is_unsafe_smbus;
 }
 #endif
@@ -152,7 +143,7 @@ static int __devinit piix4_setup(struct pci_dev *PIIX4_dev,
 		pci_read_config_word(PIIX4_dev, SMBBA, &piix4_smba);
 		piix4_smba &= 0xfff0;
 		if(piix4_smba == 0) {
-			printk(KERN_ERR "i2c-piix4.o: SMB base address "
+			printk(KERN_ERR "i2c-piix4.o: SMBus base address "
 				"uninitialized - upgrade BIOS or use "
 				"force_addr=0xaddr\n");
 			return -ENODEV;
@@ -160,7 +151,7 @@ static int __devinit piix4_setup(struct pci_dev *PIIX4_dev,
 	}
 
 	if (!request_region(piix4_smba, SMBIOSIZE, piix4_driver.name)) {
-		printk(KERN_ERR "i2c-piix4.o: SMB region 0x%x already in "
+		printk(KERN_ERR "i2c-piix4.o: SMBus region 0x%x already in "
 			"use!\n", piix4_smba);
 		return -ENODEV;
 	}
@@ -378,12 +369,7 @@ s32 piix4_access(struct i2c_adapter * adap, u16 addr,
 
 
 	switch (size) {
-	case PIIX4_BYTE:	/* Where is the result put? I assume here it is in
-				   SMBHSTDAT0 but it might just as well be in the
-				   SMBHSTCMD. No clue in the docs */
-
-		data->byte = inb_p(SMBHSTDAT0);
-		break;
+	case PIIX4_BYTE:
 	case PIIX4_BYTE_DATA:
 		data->byte = inb_p(SMBHSTDAT0);
 		break;
@@ -438,7 +424,7 @@ static struct i2c_adapter piix4_adapter = {
 #define PCI_DEVICE_ID_ATI_IXP200_SMBUS	0x4353
 #define PCI_DEVICE_ID_ATI_IXP300_SMBUS	0x4363
 #define PCI_DEVICE_ID_ATI_IXP400_SMBUS	0x4372
-#define PCI_DEVICE_ID_ATI_IXP600_SMBUS	0x4385
+#define PCI_DEVICE_ID_ATI_SBX00_SMBUS	0x4385
 
 #ifndef PCI_DEVICE_ID_SERVERWORKS_CSB6
 #define PCI_DEVICE_ID_SERVERWORKS_CSB6 0x0203
@@ -477,7 +463,7 @@ static struct pci_device_id piix4_ids[] __devinitdata = {
 	},
 	{
 		.vendor =	PCI_VENDOR_ID_ATI,
-		.device =	PCI_DEVICE_ID_ATI_IXP600_SMBUS,
+		.device =	PCI_DEVICE_ID_ATI_SBX00_SMBUS,
 		.subvendor =	PCI_ANY_ID,
 		.subdevice =	PCI_ANY_ID,
 		.driver_data =	0,
