@@ -31,8 +31,8 @@
 
 void help(void)
 {
-	fprintf(stderr, "Syntax: i2cdump [-y] I2CBUS ADDRESS [MODE] [BANK "
-	        "[BANKREG]]\n"
+	fprintf(stderr, "Syntax: i2cdump [-f] [-y] I2CBUS ADDRESS [MODE] "
+	        "[BANK [BANKREG]]\n"
 	        "        i2cdump -V\n"
 	        "  MODE is one of:\n"
 		"    b (byte, default)\n"
@@ -60,12 +60,13 @@ int main(int argc, char *argv[])
 	int block[256], s_length = 0;
 	int pec = 0, even = 0;
 	int flags = 0;
-	int yes = 0, version = 0;
+	int force = 0, yes = 0, version = 0;
 
 	/* handle (optional) flags first */
 	while (1+flags < argc && argv[1+flags][0] == '-') {
 		switch (argv[1+flags][1]) {
 		case 'V': version = 1; break;
+		case 'f': force = 1; break;
 		case 'y': yes = 1; break;
 		default:
 			fprintf(stderr, "Warning: Unsupported flag "
@@ -234,13 +235,8 @@ int main(int argc, char *argv[])
 		break;
 	}
 
-	/* use FORCE so that we can look at registers even when
-	   a driver is also running */
-	if (ioctl(file, I2C_SLAVE_FORCE, address) < 0) {
-		fprintf(stderr, "Error: Could not set address to %d: %s\n",
-		        address, strerror(errno));
+	if (set_slave_addr(file, address, force) < 0)
 		exit(1);
-	}
 
 	if (pec) {
 		if (ioctl(file, I2C_PEC, 1) < 0) {
@@ -248,7 +244,7 @@ int main(int argc, char *argv[])
 			        strerror(errno));
 			exit(1);
 		}
-		if (!(funcs & (I2C_FUNC_SMBUS_HWPEC_CALC | I2C_FUNC_I2C))) {
+		if (!(funcs & (I2C_FUNC_SMBUS_PEC | I2C_FUNC_I2C))) {
 			fprintf(stderr, "Warning: Adapter for i2c bus %d does "
 			        "not seem to actually support PEC\n", i2cbus);
 		}
@@ -316,9 +312,11 @@ int main(int argc, char *argv[])
 			} else {
 				for (res = 0; res < 256; res += i) {
 					i = i2c_smbus_read_i2c_block_data(file,
-						res, cblock + res);
-					if (i <= 0)
+						res, 32, cblock + res);
+					if (i <= 0) {
+						res = i;
 						break;
+					}
 				}
 			}
 			if (res <= 0) {
