@@ -152,7 +152,7 @@ int main(int argc, char **argv){
 	    fprintf(stderr,"Note on pages/addresses:\n");
 	    fprintf(stderr,"\teeproms with more than 256 byte appear as if they\n");
 	    fprintf(stderr,"\twere several eeproms with consecutive addresses on the bus\n");
-	    fprintf(stderr,"\tso we might as well address several seperate eeproms with\n");
+	    fprintf(stderr,"\tso we might as well address several separate eeproms with\n");
 	    fprintf(stderr,"\tincreasing addresses....\n\n");
 	    exit(1);
 	    break;
